#
# spec file for package libisds
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define libname %{name}5
Name:           libisds
Version:        0.11.2
Release:        2.1
Summary:        Library for accessing the Czech Data Boxes
License:        LGPL-3.0-or-later
Group:          Development/Libraries/C and C++
URL:            http://xpisar.wz.cz/libisds/
Source0:        http://xpisar.wz.cz/%{name}/dist/%{name}-%{version}.tar.xz
Source1:        http://xpisar.wz.cz/%{name}/dist/%{name}-%{version}.tar.xz.asc
Source2:        %{name}.keyring
Patch0:         libisds-build-fix.patch
BuildRequires:  docbook-xsl-stylesheets
BuildRequires:  gpg2
BuildRequires:  libgcrypt-devel
BuildRequires:  libgpgme-devel
BuildRequires:  pkgconfig
BuildRequires:  xsltproc
BuildRequires:  pkgconfig(expat) >= 2.0.0
BuildRequires:  pkgconfig(gnutls) >= 2.12.0
BuildRequires:  pkgconfig(libcrypto)
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(libxml-2.0)
Requires:       gpg2

%description
This is a library for accessing ISDS (Informační systém datových schránek /
Data Box Information System) SOAP services as defined in Czech ISDS Act
(300/2008 Coll.) and implied documents.

%package -n %{libname}
Summary:        Library for accessing the Czech Data Boxes
Group:          System/Libraries

%description -n %{libname}
This is a library for accessing ISDS (Informační systém datových schránek /
Data Box Information System) SOAP services as defined in Czech ISDS Act
(300/2008 Coll.) and implied documents.

%package        devel
Summary:        Development files for %{name}
Group:          Development/Languages/C and C++
Requires:       %{libname} = %{version}

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%prep
%autosetup -p1

%build
%configure \
  --disable-fatalwarnings \
  --disable-static \
  --enable-test \
  --with-docbook-xsl-stylesheets=%{_datadir}/xml/docbook/stylesheet/nwalsh/current/ \
  --with-libcurl \
  --disable-openssl-backend
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
%find_lang %{name}
mv doc specification
rm -rf client/.deps
rm -f specification/Makefile*
rm -f specification/*.3

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname} -f %{name}.lang
%license COPYING
%doc README AUTHORS NEWS TODO
%{_libdir}/*.so.*

%files devel
%{_includedir}/isds.h
%{_libdir}/*.so
%{_libdir}/pkgconfig/%{name}.pc
%{_mandir}/man3/*.3%{?ext_man}
%doc client specification

%changelog
* Fri Nov 15 2024 Marcus Meissner <meissner@suse.com>
- libisds-build-fix.patch:  fix build with gcc14
* Sat Dec  3 2022 Dirk Müller <dmueller@suse.com>
- update to 0.11.2:
  * A build failure with Musl C library and new warnings with GCC 12 were fixed.
  * Building with GCC 10, which defaults to tentative definitions of global
    variables now as with -fno-common option and resulted into
    an error about multiple definitions of a variable, was fixed.
- drop tests-Fix-building-with-GCC-10.patch (upstream)
* Fri Jun  5 2020 Jiri Slaby <jslaby@suse.com>
- add tests-Fix-building-with-GCC-10.patch
* Thu Nov 28 2019 Jiri Slaby <jslaby@suse.com>
- Version bump to 0.11:
  * mobile key authentication
  * manual pages are generated
  * compatibility with OpenSSL 1.1.0
- drop %%check as it does nothing (and breaks build ATM)
- Drop merged patch fix-gnutls-3.6.4.patch
* Sun Jun  2 2019 Jan Engelhardt <jengelh@inai.de>
- Adjust SRPM group.
* Wed May 22 2019 Pedro Monreal Gonzalez <pmonrealgonzalez@suse.com>
- Use the default GPGme library instead of OpenSSL [bsc#1135761]
* Tue May 21 2019 Jiri Slaby <jslaby@suse.com>
- add fix-gnutls-3.6.4.patch (fixes build)
* Mon Aug 13 2018 tchvatal@suse.com
- Version bump to 0.10.8:
  * Various memory leaks fixed
  * Recognise EV8
* Wed Jul 19 2017 jslaby@suse.com
- Version bump to 0.10.7:
  * l10n: Update translation catalogues
  * doc: Annotate documentation for new box types
  * Added OVM_FO, OVM_PFO and OVM_PO box types.
  * Add missing user and sender types to example client...
  * Added PFO_AUDITOR box type.
  * Added RECEIVER and GUARDIAN user types.
* Sun Jun  4 2017 tchvatal@suse.com
- Disable werror
* Thu Oct 20 2016 jslaby@suse.com
- Version bump to 0.10.6:
  * l10n: Update translation catalogues
  * Adapt to OpenSSL 1.1.0
* Mon Oct 10 2016 jslaby@suse.com
- Version bump to 0.10.5:
  * l10n: Update translation catalogues
  * Added a new value into isds_DbState.
  * Fixed a bug. User identification didn't work properly.
* Mon Apr 11 2016 mpluskal@suse.com
- Add gpg signature
- Small cleanup with spec-cleaner
  * use valid rpm category
  * use pkgconfig() style dependencies
-Update build dependencies
  * add gpgme-devel
* Mon Apr 11 2016 jslaby@suse.com
- Version bump to 0.10.3:
  * l10n: Update translation catalogues
  * Correct _isds_build_url_from_context() documentation
  * Do not use dolar in formatting strings
  * Fixed a potential bug when printing debugging information.
  * Fix building without libcurl
* Mon Sep  7 2015 tchvatal@suse.com
- Version bump to 0.10.1:
  * Fix expired certificates so the testsuite pass again
* Mon Jan 12 2015 tchvatal@suse.com
- Cleanup for openSUSE
- Version bump to 0.10:
  * A new ISDSSearch2 service was implemented by an isds_find_box_by_fulltext()
    function.
  * The OpenSSL library can be used instead of the default GPGme library by
    specifying --enable-openssl-backend option to the configure script.
  * When parsing ISO 8601 date-time strings from a server response, microsecond
    fractions are properly rounded (half up) now.
  * An use-after-free bug in parsing SOAP response has been fixed.
  * Handling su_seconds_t type used in the timeval structure was corrected to
    enable flawless compilation with Mac OS X standard library.
  * Various signedness mismataches which could lead to an undefined behaviour
    were fixed.
  * A work-around for accessing the strdup(3) function in Mac OS X standard
    library was applied.
* Tue Aug 12 2014 ppisar@redhat.com
- 0.9 bump
* Wed Apr  2 2014 ppisar@redhat.com
- Use _DEFAULT_SOURCE where _BSD_SOURCE macro presents to satisfy glibc-2.19.90
* Mon Oct 21 2013 ppisar@redhat.com
- 0.8 bump
* Wed Mar 27 2013 ppisar@redhat.com
- Update config.sub to support aarch64 (bug #925782)
* Thu Jan  3 2013 ppisar@redhat.com
- 0.7 bump
* Wed Oct 31 2012 ppisar@redhat.com
- 0.6.2 bump
* Tue Oct 30 2012 ppisar@redhat.com
- 0.6.1 bump
* Thu Mar  3 2011 ppisar@redhat.com
- 0.5 bump (breaks ABI, API preserved)
- Remove aplied patch and GPG hack
* Fri Feb 11 2011 ppisar@redhat.com
- Rebuild with GCC 4.6
- Remove BuildRoot stuff
- Make devel subpackage dependencies ISA specific
* Mon Dec 20 2010 ppisar@redhat.com
- 0.4 bump, it breaks ABI
- Use smaller xz archive instead of bzip2
- Do tests in parallel
* Tue Jun 29 2010 ppisar@redhat.com
- 0.3.1 version bump
- Create ~/.gnupg to workaround bug in gnupg2-smime
* Tue Apr 13 2010 ppisar@redhat.com
- New version 0.2.1 released by upstream
* Thu Feb 11 2010 mcepl@redhat.com
- Fixing small issue with documentation for package review
* Tue Feb  9 2010 mcepl@redhat.com
- Initial packaging effort
